@@ -30,7 +30,7 @@ namespace BluezQt
 
 AdapterPrivate::AdapterPrivate(const QString &path, const QVariantMap &properties)
     : QObject()
-    , m_dbusProperties(0)
+    , m_dbusProperties(nullptr)
     , m_adapterClass(0)
     , m_powered(0)
     , m_discoverable(false)
@@ -48,14 +48,6 @@ void AdapterPrivate::init(const QVariantMap &properties)
     m_dbusProperties = new DBusProperties(Strings::orgBluez(), m_bluezAdapter->path(),
                                           DBusConnection::orgBluez(), this);
 
-    // QueuedConnection is important here to be able to perform actions, that depend on
-    // a previously set property, directly from slot connected to propertyChanged signal.
-    // Eg. Powering on adapter and then starting discovery.
-    //  * with DirectConnection the StartDiscovery would fail because the adapter is still
-    //    powered off when the PropertiesChanged signal is emitted ...
-    connect(m_dbusProperties, &DBusProperties::PropertiesChanged,
-            this, &AdapterPrivate::propertiesChanged, Qt::QueuedConnection);
-
     // Init properties
     m_address = properties.value(QStringLiteral("Address")).toString();
     m_name = properties.value(QStringLiteral("Name")).toString();
@@ -71,7 +63,7 @@ void AdapterPrivate::init(const QVariantMap &properties)
     m_modalias = properties.value(QStringLiteral("Modalias")).toString();
 }
 
-void AdapterPrivate::addDevice(DevicePtr device)
+void AdapterPrivate::addDevice(const DevicePtr &device)
 {
     m_devices.append(device);
     Q_EMIT q.data()->deviceAdded(device);
@@ -79,11 +71,13 @@ void AdapterPrivate::addDevice(DevicePtr device)
     connect(device.data(), &Device::deviceChanged, q.data(), &Adapter::deviceChanged);
 }
 
-void AdapterPrivate::removeDevice(DevicePtr device)
+void AdapterPrivate::removeDevice(const DevicePtr &device)
 {
     m_devices.removeOne(device);
     Q_EMIT device->deviceRemoved(device);
     Q_EMIT q.data()->deviceRemoved(device);
+
+    disconnect(device.data(), &Device::deviceChanged, q.data(), &Adapter::deviceChanged);
 }
 
 QDBusPendingReply<> AdapterPrivate::setDBusProperty(const QString &name, const QVariant &value)
@@ -123,7 +117,7 @@ void AdapterPrivate::propertiesChanged(const QString &interface, const QVariantM
         } else if (property == QLatin1String("Modalias")) {
             PROPERTY_CHANGED(m_modalias, toString, modaliasChanged);
         } else if (property == QLatin1String("UUIDs")) {
-            uuidsPropertyChanged(stringListToUpper(value.toStringList()));
+            PROPERTY_CHANGED2(m_uuids, stringListToUpper(value.toStringList()), uuidsChanged);
         }
     }
 
@@ -136,14 +130,4 @@ void AdapterPrivate::propertiesChanged(const QString &interface, const QVariantM
     Q_EMIT q.data()->adapterChanged(q.toStrongRef());
 }
 
-void AdapterPrivate::uuidsPropertyChanged(const QStringList &value)
-{
-    if (m_uuids != value) {
-        m_uuids = value;
-        Q_EMIT q.data()->uuidsChanged(m_uuids);
-    }
-}
-
-#undef PROPERTY_CHANGED
-
 } // namespace BluezQt
